@@ -451,13 +451,13 @@ class WebDriver (ElementLocation):
         theseWebElems=[]
         for arg in args:
             theseWebElems.append(arg.webElement)
-        return self.driver.execute_async_script(script,theseWebElems)
+        return self.driver.execute_async_script(f"arguments=arguments[0];{script}",theseWebElems)
 
     def execute_script(self,script, *args):
         theseWebElems=[]
         for arg in args:
             theseWebElems.append(arg.webElement)
-        return self.driver.execute_script(script,theseWebElems)
+        return self.driver.execute_script(f"arguments=arguments[0];{script}",theseWebElems)
 
     def forward(self):
         return self.driver.forward()
